EXPORTS
	??1CUniDataModel@@UAE@XZ @ 1 NONAME ; CUniDataModel::~CUniDataModel(void)
	?AddAttachmentL@CUniDataModel@@QAEPAVCUniObject@@AAVMUniObjectSaveObserver@@PAVCMsgMediaInfo@@W4TMsvAttachmentType@CMsvAttachment@@@Z @ 2 NONAME ; class CUniObject * CUniDataModel::AddAttachmentL(class MUniObjectSaveObserver &, class CMsgMediaInfo *, enum CMsvAttachment::TMsvAttachmentType)
	?AddObjectL@CUniObjectList@@QAEXPAVCUniObject@@@Z @ 3 NONAME ; void CUniObjectList::AddObjectL(class CUniObject *)
	?AddObjectL@CUniSmilModel@@QAEPAVCUniObject@@AAVMUniObjectSaveObserver@@HPAVCMsgMediaInfo@@@Z @ 4 NONAME ; class CUniObject * CUniSmilModel::AddObjectL(class MUniObjectSaveObserver &, int, class CMsgMediaInfo *)
	?AddSlideL@CUniSmilModel@@QAEXH@Z @ 5 NONAME ; void CUniSmilModel::AddSlideL(int)
	?AddSmilAttachmentL@CUniSmilList@@QAEXAAVMMsvAttachmentManager@@I@Z @ 6 NONAME ; void CUniSmilList::AddSmilAttachmentL(class MMsvAttachmentManager &, unsigned int)
	?AddStoredAttachmentL@CUniDataModel@@QAEPAVCUniObject@@IPAVCMsgMediaInfo@@@Z @ 7 NONAME ; class CUniObject * CUniDataModel::AddStoredAttachmentL(unsigned int, class CMsgMediaInfo *)
	?AddStoredObjectL@CUniSmilModel@@QAEPAVCUniObject@@HIPAVCMsgMediaInfo@@@Z @ 8 NONAME ; class CUniObject * CUniSmilModel::AddStoredObjectL(int, unsigned int, class CMsgMediaInfo *)
	?AddTextObjectL@CUniSmilModel@@QAEPAVCUniTextObject@@HPAVCEikRichTextEditor@@@Z @ 9 NONAME ; class CUniTextObject * CUniSmilModel::AddTextObjectL(int, class CEikRichTextEditor *)
	?ChangeLayoutL@CUniSmilModel@@QAEHPAVCMDXMLDocument@@@Z @ 10 NONAME ; int CUniSmilModel::ChangeLayoutL(class CMDXMLDocument *)
	?CharconvIdToMibIdL@CUniDataUtils@@QAEII@Z @ 11 NONAME ; unsigned int CUniDataUtils::CharconvIdToMibIdL(unsigned int)
	?ComposeL@CUniSmilModel@@QAEPAVCMDXMLDocument@@XZ @ 12 NONAME ; class CMDXMLDocument * CUniSmilModel::ComposeL(void)
	?ConstructL@CUniDataModel@@AAEXXZ @ 13 NONAME ; void CUniDataModel::ConstructL(void)
	?ConsumeRights@CUniDrmInfo@@QAEHXZ @ 14 NONAME ; int CUniDrmInfo::ConsumeRights(void)
	?CorrectTimingL@CUniSmilModel@@QAEHPAVCMDXMLDocument@@@Z @ 15 NONAME ; int CUniSmilModel::CorrectTimingL(class CMDXMLDocument *)
	?CreateSmilAttachmentL@CUniSmilList@@QAEXAAVMUniSmilComposeObserver@@AAVCMsvStore@@PAVCMDXMLDocument@@@Z @ 16 NONAME ; void CUniSmilList::CreateSmilAttachmentL(class MUniSmilComposeObserver &, class CMsvStore &, class CMDXMLDocument *)
	?EnsureAllObjectsHaveContentLocationL@CUniObjectList@@QAEXXZ @ 17 NONAME ; void CUniObjectList::EnsureAllObjectsHaveContentLocationL(void)
	?EvaluateRights@CUniDrmInfo@@QAEHAAH@Z @ 18 NONAME ; int CUniDrmInfo::EvaluateRights(int &)
	?FileSizeL@CUniDataUtils@@QAEHABV?$TBuf@$0BAA@@@@Z @ 19 NONAME ; int CUniDataUtils::FileSizeL(class TBuf<256> const &)
	?FreezeRights@CUniDrmInfo@@QAEHXZ @ 20 NONAME ; int CUniDrmInfo::FreezeRights(void)
	?GetAttachmentFileL@CUniDataUtils@@SA?AVRFile@@AAVCBaseMtm@@I@Z @ 21 NONAME ; class RFile CUniDataUtils::GetAttachmentFileL(class CBaseMtm &, unsigned int)
	?GetByAttachmentId@CUniObjectList@@QAEPAVCUniObject@@I@Z @ 22 NONAME ; class CUniObject * CUniObjectList::GetByAttachmentId(unsigned int)
	?GetByIndex@CUniObjectList@@QAEPAVCUniObject@@H@Z @ 23 NONAME ; class CUniObject * CUniObjectList::GetByIndex(int)
	?GetByNodeL@CUniObjectList@@QAEPAVCUniObject@@PAVCMDXMLNode@@@Z @ 24 NONAME ; class CUniObject * CUniObjectList::GetByNodeL(class CMDXMLNode *)
	?GetByUrlL@CUniObjectList@@QAEPAVCUniObject@@ABVTDesC16@@@Z @ 25 NONAME ; class CUniObject * CUniObjectList::GetByUrlL(class TDesC16 const &)
	?GetCharacterSetL@CUniObjectList@@UAEIABVTDesC16@@@Z @ 26 NONAME ; unsigned int CUniObjectList::GetCharacterSetL(class TDesC16 const &)
	?GetFileHandleL@CUniObjectList@@UAEXABVTDesC16@@AAVRFile@@@Z @ 27 NONAME ; void CUniObjectList::GetFileHandleL(class TDesC16 const &, class RFile &)
	?GetId@UniSmilUtils@@SAHPAVCMDXMLNode@@AAVTPtrC16@@@Z @ 28 NONAME ; int UniSmilUtils::GetId(class CMDXMLNode *, class TPtrC16 &)
	?GetMetaTag@UniSmilUtils@@SAHPAVCMDXMLNode@@AAVTPtrC16@@1@Z @ 29 NONAME ; int UniSmilUtils::GetMetaTag(class CMDXMLNode *, class TPtrC16 &, class TPtrC16 &)
	?GetMimeTypeL@CUniObjectList@@UAE?AVTPtrC8@@ABVTDesC16@@@Z @ 30 NONAME ; class TPtrC8 CUniObjectList::GetMimeTypeL(class TDesC16 const &)
	?GetObject@CUniSmilModel@@QBEPAVCUniObject@@HW4TUniRegion@@@Z @ 31 NONAME ; class CUniObject * CUniSmilModel::GetObject(int, enum TUniRegion) const
	?GetObjectByIndex@CUniSmilModel@@QBEPAVCUniObject@@HH@Z @ 32 NONAME ; class CUniObject * CUniSmilModel::GetObjectByIndex(int, int) const
	?GetObjectByUniqueHandle@CUniObjectList@@QAEPAVCUniObject@@H@Z @ 33 NONAME ; class CUniObject * CUniObjectList::GetObjectByUniqueHandle(int)
	?GetRegionId@UniSmilUtils@@SAHPAVCMDXMLNode@@AAVTPtrC16@@@Z @ 34 NONAME ; int UniSmilUtils::GetRegionId(class CMDXMLNode *, class TPtrC16 &)
	?GetSmilAttachmentByIndex@CUniSmilList@@QAEIH@Z @ 35 NONAME ; unsigned int CUniSmilList::GetSmilAttachmentByIndex(int)
	?GetSmilFileByIndexL@CUniSmilList@@QAE?AVRFile@@H@Z @ 36 NONAME ; class RFile CUniSmilList::GetSmilFileByIndexL(int)
	?GetSmilTypeL@UniSmilUtils@@SA?AW4TUniSmilType@@PAVCMDXMLDocument@@@Z @ 37 NONAME ; enum TUniSmilType UniSmilUtils::GetSmilTypeL(class CMDXMLDocument *)
	?GetSrcL@UniSmilUtils@@SA?AVTPtrC16@@PAVCMDXMLNode@@@Z @ 38 NONAME ; class TPtrC16 UniSmilUtils::GetSrcL(class CMDXMLNode *)
	?HandleDrmErrorL@CUniDrmInfo@@QAEXH@Z @ 39 NONAME ; void CUniDrmInfo::HandleDrmErrorL(int)
	?IndexPositionOfAttachmentL@CUniDataUtils@@SAHAAVMMsvAttachmentManager@@I@Z @ 40 NONAME ; int CUniDataUtils::IndexPositionOfAttachmentL(class MMsvAttachmentManager &, unsigned int)
	?IsDrmWithOnePreview@CUniDrmInfo@@QAEHXZ @ 41 NONAME ; int CUniDrmInfo::IsDrmWithOnePreview(void)
	?IsMediaElem@UniSmilUtils@@SAHPAVCMDXMLNode@@@Z @ 42 NONAME ; int UniSmilUtils::IsMediaElem(class CMDXMLNode *)
	?IsSlide@CUniSmilModel@@QBEHH@Z @ 43 NONAME ; int CUniSmilModel::IsSlide(int) const
	?IsSupportedMediaType@CUniSmilModel@@QBEHW4TMsgMediaType@@@Z @ 44 NONAME ; int CUniSmilModel::IsSupportedMediaType(enum TMsgMediaType) const
	?IsTemplateSmil@UniSmilUtils@@SAHPAVCMDXMLDocument@@@Z @ 45 NONAME ; int UniSmilUtils::IsTemplateSmil(class CMDXMLDocument *)
	?MediaElemType@UniSmilUtils@@SA?AW4TMsgMediaType@@PAVCMDXMLNode@@@Z @ 46 NONAME ; enum TMsgMediaType UniSmilUtils::MediaElemType(class CMDXMLNode *)
	?MediaType@CUniObject@@QBE?AW4TMsgMediaType@@XZ @ 47 NONAME ; enum TMsgMediaType CUniObject::MediaType(void) const
	?MibIdToCharconvIdL@CUniDataUtils@@QAEII@Z @ 48 NONAME ; unsigned int CUniDataUtils::MibIdToCharconvIdL(unsigned int)
	?MimeType@CUniObject@@QBE?AVTPtrC8@@XZ @ 49 NONAME ; class TPtrC8 CUniObject::MimeType(void) const
	?MoveSlideL@CUniSmilModel@@QAEXHH@Z @ 50 NONAME ; void CUniSmilModel::MoveSlideL(int, int)
	?NewL@CUniDataModel@@SAPAV1@AAVRFs@@AAVCBaseMtm@@@Z @ 51 NONAME ; class CUniDataModel * CUniDataModel::NewL(class RFs &, class CBaseMtm &)
	?NewL@CUniDataUtils@@SAPAV1@AAVRFs@@@Z @ 52 NONAME ; class CUniDataUtils * CUniDataUtils::NewL(class RFs &)
	?NewL@CUniDrmInfo@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAIAAVCMsgMediaInfo@@@Z @ 53 NONAME ; class CUniDrmInfo * CUniDrmInfo::NewL(class RFs &, class CBaseMtm &, unsigned int &, class CMsgMediaInfo &)
	?NewL@CUniObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgMediaInfo@@@Z @ 54 NONAME ; class CUniObject * CUniObject::NewL(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgMediaInfo *)
	?NewL@CUniObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgMediaInfo@@AAVMMsvAttachmentManager@@AAVCMsvAttachment@@@Z @ 55 NONAME ; class CUniObject * CUniObject::NewL(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgMediaInfo *, class MMsvAttachmentManager &, class CMsvAttachment &)
	?NewL@CUniObjectList@@SAPAV1@AAVCBaseMtm@@AAVCUniDataUtils@@@Z @ 56 NONAME ; class CUniObjectList * CUniObjectList::NewL(class CBaseMtm &, class CUniDataUtils &)
	?NewL@CUniSmilList@@SAPAV1@AAVCBaseMtm@@@Z @ 57 NONAME ; class CUniSmilList * CUniSmilList::NewL(class CBaseMtm &)
	?NewL@CUniSmilModel@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@AAVCUniObjectList@@@Z @ 58 NONAME ; class CUniSmilModel * CUniSmilModel::NewL(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CUniObjectList &)
	?NewL@CUniSmilParams@@SAPAV1@ABVRFs@@@Z @ 59 NONAME ; class CUniSmilParams * CUniSmilParams::NewL(class RFs const &)
	?NewL@CUniTextObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCEikRichTextEditor@@@Z @ 60 NONAME ; class CUniTextObject * CUniTextObject::NewL(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CEikRichTextEditor *)
	?NewL@CUniTextObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgTextInfo@@@Z @ 61 NONAME ; class CUniTextObject * CUniTextObject::NewL(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgTextInfo *)
	?NewL@CUniTextObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgTextInfo@@AAVMMsvAttachmentManager@@AAVCMsvAttachment@@@Z @ 62 NONAME ; class CUniTextObject * CUniTextObject::NewL(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgTextInfo *, class MMsvAttachmentManager &, class CMsvAttachment &)
	?NewLC@CUniDrmInfo@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAIAAVCMsgMediaInfo@@@Z @ 63 NONAME ; class CUniDrmInfo * CUniDrmInfo::NewLC(class RFs &, class CBaseMtm &, unsigned int &, class CMsgMediaInfo &)
	?NewLC@CUniObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgMediaInfo@@@Z @ 64 NONAME ; class CUniObject * CUniObject::NewLC(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgMediaInfo *)
	?NewLC@CUniObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgMediaInfo@@AAVMMsvAttachmentManager@@AAVCMsvAttachment@@@Z @ 65 NONAME ; class CUniObject * CUniObject::NewLC(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgMediaInfo *, class MMsvAttachmentManager &, class CMsvAttachment &)
	?NewLC@CUniSmilModel@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@AAVCUniObjectList@@@Z @ 66 NONAME ; class CUniSmilModel * CUniSmilModel::NewLC(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CUniObjectList &)
	?NewLC@CUniSmilParams@@SAPAV1@ABVRFs@@@Z @ 67 NONAME ; class CUniSmilParams * CUniSmilParams::NewLC(class RFs const &)
	?NewLC@CUniTextObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCEikRichTextEditor@@@Z @ 68 NONAME ; class CUniTextObject * CUniTextObject::NewLC(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CEikRichTextEditor *)
	?NewLC@CUniTextObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgTextInfo@@@Z @ 69 NONAME ; class CUniTextObject * CUniTextObject::NewLC(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgTextInfo *)
	?NewLC@CUniTextObject@@SAPAV1@AAVRFs@@AAVCBaseMtm@@AAVCUniDataUtils@@PAVCMsgTextInfo@@AAVMMsvAttachmentManager@@AAVCMsvAttachment@@@Z @ 70 NONAME ; class CUniTextObject * CUniTextObject::NewLC(class RFs &, class CBaseMtm &, class CUniDataUtils &, class CMsgTextInfo *, class MMsvAttachmentManager &, class CMsvAttachment &)
	?NextNode@UniSmilUtils@@SAPAVCMDXMLNode@@PAV2@@Z @ 71 NONAME ; class CMDXMLNode * UniSmilUtils::NextNode(class CMDXMLNode *)
	?ObjectByteSize@CUniObjectList@@QBEHXZ @ 72 NONAME ; int CUniObjectList::ObjectByteSize(void) const
	?ObjectCount@CUniSmilModel@@QBEHXZ @ 73 NONAME ; int CUniSmilModel::ObjectCount(void) const
	?ParseL@CUniSmilModel@@QAEHPAVCMDXMLDocument@@@Z @ 74 NONAME ; int CUniSmilModel::ParseL(class CMDXMLDocument *)
	?ReleaseRights@CUniDrmInfo@@QAEHXZ @ 75 NONAME ; int CUniDrmInfo::ReleaseRights(void)
	?RemoveAllObjectsL@CUniObjectList@@QAEXXZ @ 76 NONAME ; void CUniObjectList::RemoveAllObjectsL(void)
	?RemoveChilds@UniSmilUtils@@SAXPAVCMDXMLNode@@@Z @ 77 NONAME ; void UniSmilUtils::RemoveChilds(class CMDXMLNode *)
	?RemoveEmptySlides@CUniSmilModel@@QAEXXZ @ 78 NONAME ; void CUniSmilModel::RemoveEmptySlides(void)
	?RemoveObjectByIndexL@CUniSmilModel@@QAEXHH@Z @ 79 NONAME ; void CUniSmilModel::RemoveObjectByIndexL(int, int)
	?RemoveObjectL@CUniObjectList@@QAEXPAVCUniObject@@H@Z @ 80 NONAME ; void CUniObjectList::RemoveObjectL(class CUniObject *, int)
	?RemoveObjectL@CUniSmilModel@@QAEXHPAVCUniObject@@H@Z @ 81 NONAME ; void CUniSmilModel::RemoveObjectL(int, class CUniObject *, int)
	?RemoveSlide@CUniSmilModel@@QAEXH@Z @ 82 NONAME ; void CUniSmilModel::RemoveSlide(int)
	?RemoveSmilL@CUniSmilList@@QAEXAAVCMsvStore@@@Z @ 83 NONAME ; void CUniSmilList::RemoveSmilL(class CMsvStore &)
	?RestoreL@CUniDataModel@@QAEXAAVMUniDataModelObserver@@HH@Z @ 84 NONAME ; void CUniDataModel::RestoreL(class MUniDataModelObserver &, int, int)
	?RightsValidL@CUniDrmInfo@@QAEHH@Z @ 85 NONAME ; int CUniDrmInfo::RightsValidL(int)
	?SaveAll@CUniObjectList@@QAEXAAVMUniObjectSaveObserver@@W4TMsvAttachmentType@CMsvAttachment@@@Z @ 86 NONAME ; void CUniObjectList::SaveAll(class MUniObjectSaveObserver &, enum CMsvAttachment::TMsvAttachmentType)
	?SetLayoutL@CUniSmilModel@@QAEXW4TUniLayout@@@Z @ 87 NONAME ; void CUniSmilModel::SetLayoutL(enum TUniLayout)
	?SetListObserver@CUniObjectList@@QAEXPAVMUniObjectListObserver@@@Z @ 88 NONAME ; void CUniObjectList::SetListObserver(class MUniObjectListObserver *)
	?SlideObjectCount@CUniSmilModel@@QBEHH@Z @ 89 NONAME ; int CUniSmilModel::SlideObjectCount(int) const
	?SmilComposeSize@CUniSmilModel@@QAEHHH@Z @ 90 NONAME ; int CUniSmilModel::SmilComposeSize(int, int)
	?SmilComposeSize@CUniSmilModel@@QAEHXZ @ 91 NONAME ; int CUniSmilModel::SmilComposeSize(void)
	?SortSlidesL@CUniSmilModel@@QAEXXZ @ 92 NONAME ; void CUniSmilModel::SortSlidesL(void)
	?SpaceNeededForSaveAll@CUniObjectList@@QAEHXZ @ 93 NONAME ; int CUniObjectList::SpaceNeededForSaveAll(void)
	?StringToIntValue@UniSmilUtils@@SAHABVTDesC16@@H@Z @ 94 NONAME ; int UniSmilUtils::StringToIntValue(class TDesC16 const &, int)
	?SynchronizeSize@CUniTextObject@@QAEHXZ @ 95 NONAME ; int CUniTextObject::SynchronizeSize(void)
	?UTF8Size@CUniDataUtils@@SAHVTPtrC16@@@Z @ 96 NONAME ; int CUniDataUtils::UTF8Size(class TPtrC16)
	?FinalizeMediaParse@CUniDataModel@@QAEXXZ @ 97 NONAME ; void CUniDataModel::FinalizeMediaParse(void)
	?SetDrmRightsWhenLoaded@CUniObject@@QAEXH@Z @ 98 NONAME ; void CUniObject::SetDrmRightsWhenLoaded(int)
	?ResolveDrmRightsWhenLoadedL@CUniObject@@QAEXXZ @ 99 NONAME ; void CUniObject::ResolveDrmRightsWhenLoadedL(void)
	?RemoveObserver@CUniObject@@QAEXPAVMUniObjectObserver@@@Z @ 100 NONAME ; void CUniObject::RemoveObserver(class MUniObjectObserver *)
	?SetObserverL@CUniObject@@QAEXPAVMUniObjectObserver@@@Z @ 101 NONAME ; void CUniObject::SetObserverL(class MUniObjectObserver *)
	?SetDrmRightsWhenLoadedObjects@CUniObject@@QAEXH@Z @ 102 NONAME ; void CUniObject::SetDrmRightsWhenLoadedObjects(int)

